==> haskell-cmark-gfm-0.1.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark-gfm
version: 0.1.3
id: cmark-gfm-0.1.3-D4NajCuHPT6J2ZXIfca2cg
key: cmark-gfm-0.1.3-D4NajCuHPT6J2ZXIfca2cg
license: BSD3
copyright: (C) 2015--17 John MacFarlane, (C) 2017 Yuki Izumi
maintainer: kivikakk@github.com
homepage: https://github.com/kivikakk/cmark-gfm-hs
synopsis: Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.28.0) and does not require prior installation of the
    C library.
category: Text
author: Yuki Izumi
exposed: True
indefinite: False
exposed-modules:
    CMarkGFM
abi: b35e0b5136d6bc980ac8f1f62d09bf59
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-gfm-0.1.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-gfm-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cmark-gfm-0.1.3
hs-libraries: HScmark-gfm-0.1.3-D4NajCuHPT6J2ZXIfca2cg
includes:
    cmark.h
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html: /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-gfm-0.1.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark-gfm
version: 0.1.3
id: cmark-gfm-0.1.3-9JIYiVDhJ65KYe2mtb4tmu
key: cmark-gfm-0.1.3-9JIYiVDhJ65KYe2mtb4tmu
license: BSD3
copyright: (C) 2015--17 John MacFarlane, (C) 2017 Yuki Izumi
maintainer: kivikakk@github.com
homepage: https://github.com/kivikakk/cmark-gfm-hs
synopsis: Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.28.0) and does not require prior installation of the
    C library.
category: Text
author: Yuki Izumi
exposed: True
indefinite: False
exposed-modules:
    CMarkGFM
abi: d22d75de2ab8c0680d26bbc3f3b0f946
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-gfm-0.1.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-gfm-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cmark-gfm-0.1.3
hs-libraries: HScmark-gfm-0.1.3-9JIYiVDhJ65KYe2mtb4tmu
includes:
    cmark.h
depends:
    base-4.10.1.0 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html: /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
